"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurablePager = exports.pageReducer = exports.pageActions = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const typesafe_actions_1 = require("typesafe-actions");
const lodash_1 = require("lodash");
const inputs_1 = require("../inputs");
const Pager_1 = require("./Pager");
const ItiReactContext_1 = require("../ItiReactContext");
const ALL = 'ALL';
const allPageSize = 10000;
function getPageSizeOptions(pageSizes, showAllOption) {
    const options = (0, lodash_1.sortBy)(pageSizes, (x) => x).map((x) => ({
        value: x,
        label: x.toString(),
    }));
    if (showAllOption)
        options.push({ value: ALL, label: 'All' });
    return options;
}
function getSkipTake(page, pageSize) {
    return {
        skip: (page - 1) * pageSize,
        take: pageSize,
    };
}
// TODO convert to Redux Toolkit or completely vanilla (no action helper library)
/** @internal */
exports.pageActions = {
    setPage: (0, typesafe_actions_1.createAction)('SET_PAGE')(),
    setPageSize: (0, typesafe_actions_1.createAction)('SET_PAGE_SIZE')(),
    showAllItems: (0, typesafe_actions_1.createAction)('SHOW_ALL_ITEMS')(),
};
/** @internal */
exports.pageReducer = (0, typesafe_actions_1.createReducer)({ page: 0, pageSize: 0 } // never used
)
    .handleAction(exports.pageActions.setPage, (state, action) => ({
    ...state,
    page: action.payload,
}))
    .handleAction(exports.pageActions.setPageSize, (state, action) => {
    const firstVisibleItemIndex = getSkipTake(state.page, state.pageSize).skip;
    const pageSize = action.payload;
    return {
        page: Math.floor(firstVisibleItemIndex / pageSize) + 1,
        pageSize,
    };
})
    .handleAction(exports.pageActions.showAllItems, () => ({
    page: 1,
    pageSize: allPageSize, // for safety, limit the number of items that can be displayed
}));
/**
 * A pagination control that lets the user select how many items to show on a
 * page.
 *
 * The default page sizes are configured in [[`ItiReactContext`]] and can be
 * overridden with the `pageSizes` prop.
 *
 * You can show an "All" option by setting `showAllOption` to true. "All"
 * actually means a `pageSize` of 10000.
 */
function ConfigurablePager({ page, pageSize, onChange, totalPages, enabled, showAllOption = false, ...props }) {
    var _a;
    const itiReactContext = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext);
    const pageSizes = (_a = props.pageSizes) !== null && _a !== void 0 ? _a : itiReactContext.configurablePager.pageSizes;
    const selectIdRef = (0, react_1.useRef)((0, iti_react_core_1.getGuid)());
    function dispatch(action) {
        const updated = (0, exports.pageReducer)({ page, pageSize }, action);
        onChange(updated.page, updated.pageSize);
    }
    return ((0, jsx_runtime_1.jsx)("div", { className: "pagination-container", children: (0, jsx_runtime_1.jsxs)("div", { className: "configurable-pager", children: [(0, jsx_runtime_1.jsx)("label", { htmlFor: selectIdRef.current, children: "Items per page" }, void 0), (0, jsx_runtime_1.jsx)(inputs_1.ValidatedSelect, { id: selectIdRef.current, name: "pageSize", value: pageSize === allPageSize ? ALL : pageSize, onChange: (pageSize) => {
                        if (pageSize === ALL) {
                            dispatch(exports.pageActions.showAllItems());
                        }
                        else {
                            dispatch(exports.pageActions.setPageSize(pageSize));
                        }
                    }, options: getPageSizeOptions(pageSizes, showAllOption), showValidation: false, validators: [], enabled: enabled }, void 0), (0, jsx_runtime_1.jsx)(Pager_1.Pager, { page: page, onPageChange: (page) => dispatch(exports.pageActions.setPage(page)), totalPages: totalPages, enabled: enabled, containerClassName: "" }, void 0)] }, void 0) }, void 0));
}
exports.ConfigurablePager = ConfigurablePager;
