"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanUpImproperlyClosedDialog = exports.Dialog = exports.ActionDialog = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const event_listener_1 = __importDefault(require("@use-it/event-listener"));
const bootstrap = __importStar(require("bootstrap"));
const SubmitButton_1 = require("../SubmitButton");
const util_1 = require("../../util");
/**
 * A [[`Dialog`]] that has an action button and a cancel button.
 */
function ActionDialog({ actionButtonText, actionButtonClass = 'btn-primary', cancelButtonText = 'Cancel', action, actionInProgress, title, modalClass, onOpen, onClose, children, focusFirst, actionButtonEnabled = true, showFooter = true, onCancel, closeRef, }) {
    let footer;
    if (showFooter) {
        footer = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(SubmitButton_1.SubmitButton, { type: "button", onClick: action, className: `btn ${actionButtonClass !== null && actionButtonClass !== void 0 ? actionButtonClass : ''}`, submitting: actionInProgress, enabled: actionButtonEnabled, children: actionButtonText }, void 0), (0, jsx_runtime_1.jsx)("button", { type: "button", className: "btn btn-secondary", "data-bs-dismiss": actionInProgress || onCancel ? '' : 'modal', onClick: onCancel, children: cancelButtonText }, void 0)] }, void 0));
    }
    return ((0, jsx_runtime_1.jsx)(Dialog, { title: title, closeRef: closeRef, modalClass: modalClass, modalFooter: footer, onOpen: onOpen, onClose: onClose, focusFirst: focusFirst, allowDismiss: !actionInProgress, children: children }, void 0));
}
exports.ActionDialog = ActionDialog;
/**
 * Wrapper around the Bootstrap dialog component.
 *
 * - **DO NOT** unmount the dialog except in the `onClose` function. This will cause
 *   the dialog to be abruptly removed without an animation.
 * - Use `closeRef` to close the dialog from the parent component.
 * - The first input element is automatically focused when the dialog opens. This can be
 *   controlled with the `focusFirst` and `focusFirstOptions` props.
 */
function Dialog({ title, onOpen, onClose, modalFooter, children, closeRef, modalClass = '', focusFirst = true, allowDismiss = true, }) {
    const elementRef = (0, react_1.useRef)(null);
    const modalRef = (0, react_1.useRef)();
    (0, react_1.useEffect)(() => {
        if (closeRef) {
            closeRef.current = () => {
                if (modalRef.current)
                    modalRef.current.hide();
            };
        }
    });
    (0, event_listener_1.default)('keydown', (e) => {
        if (e.key === 'Escape' && allowDismiss && elementRef.current) {
            if (modalRef.current)
                modalRef.current.hide();
        }
    });
    // dependencies = [] because this effect should only run once. By design, a Dialog
    // instance can only be opened once.
    /* eslint-disable react-hooks/exhaustive-deps */
    (0, react_1.useEffect)(() => {
        const el = elementRef.current;
        if (!el)
            throw new Error('modal element ref is not initialized.');
        // keyboard: false because we handle closing the modal when Escape is pressed ourselves
        modalRef.current = new bootstrap.Modal(el, {
            backdrop: 'static',
            keyboard: false,
        });
        modalRef.current.show();
        if (!focusFirst)
            return undefined;
        // Focus the first field. autofocus attribute does not work in Bootstrap modals
        function shownHandler() {
            if (!el)
                throw new Error('el is null. Should be impossible.');
            (0, util_1.focusFirstInput)(el);
        }
        el.addEventListener('shown.bs.modal', shownHandler);
        return () => {
            el.removeEventListener('shown.bs.modal', shownHandler);
        };
    }, []);
    /* eslint-enable react-hooks/exhaustive-deps */
    const onOpenRef = (0, react_1.useRef)(onOpen);
    const onCloseRef = (0, react_1.useRef)(onClose);
    (0, react_1.useEffect)(() => {
        onOpenRef.current = onOpen;
        onCloseRef.current = onClose;
    });
    (0, react_1.useEffect)(() => {
        if (!elementRef.current)
            throw new Error('modal element ref is not initialized.');
        elementRef.current.addEventListener('shown.bs.modal', () => {
            if (onOpenRef.current)
                onOpenRef.current();
        });
        elementRef.current.addEventListener('hidden.bs.modal', () => {
            onCloseRef.current();
        });
    }, []);
    return ((0, jsx_runtime_1.jsx)("div", { ref: elementRef, className: "modal fade", tabIndex: -1, role: "dialog", children: (0, jsx_runtime_1.jsx)("div", { className: `modal-dialog ${modalClass}`, role: "document", children: (0, jsx_runtime_1.jsxs)("div", { className: "modal-content", children: [(0, jsx_runtime_1.jsxs)("div", { className: "modal-header", children: [(0, jsx_runtime_1.jsx)("h5", { className: "modal-title", children: title }, void 0), (0, jsx_runtime_1.jsx)("button", { type: "button", className: "btn-close", "data-bs-dismiss": allowDismiss ? 'modal' : undefined, "aria-label": "Close" }, void 0)] }, void 0), (0, jsx_runtime_1.jsx)("div", { className: "modal-body", children: children }, void 0), modalFooter && (0, jsx_runtime_1.jsx)("div", { className: "modal-footer", children: modalFooter }, void 0)] }, void 0) }, void 0) }, void 0));
}
exports.Dialog = Dialog;
function cleanUpImproperlyClosedDialog() {
    document.body.classList.remove('modal-open');
    document.body.removeAttribute('style');
    const backdrop = document.querySelector('.modal-backdrop');
    if (backdrop && backdrop.parentElement) {
        backdrop.parentElement.removeChild(backdrop);
    }
}
exports.cleanUpImproperlyClosedDialog = cleanUpImproperlyClosedDialog;
