"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SavedMessage = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const free_solid_svg_icons_1 = require("@fortawesome/free-solid-svg-icons");
const react_fontawesome_1 = require("@fortawesome/react-fontawesome");
const react_1 = require("react");
/**
 * Shows a "✔ Saved" message next to your "Save changes" button to show that
 * user that the change went through. The message fades in and out.
 *
 * ```
 * const showSavedMessageRef = useRef(() => {})
 *
 * function saveChanges() {
 *     // call the API
 *
 *     showSavedMessageRef.current()
 * }
 *
 * return <div>
 *     ...
 *      <SavedMessage
 *          showSavedMessageRef={showSavedMessageRef}
 *          className="saved-message-me"
 *      />
 *     ...
 * </div>
 * ```
 */
function SavedMessage({ showSavedMessageRef, className, }) {
    const [show, setShow] = (0, react_1.useState)(false);
    const timerRef = (0, react_1.useRef)();
    function onSave() {
        setShow(true);
        clearTimeout(timerRef.current);
        timerRef.current = window.window.setTimeout(() => setShow(false), 1800);
    }
    (0, react_1.useEffect)(() => {
        showSavedMessageRef.current = onSave;
    });
    (0, react_1.useEffect)(() => () => {
        clearTimeout(timerRef.current);
    }, []);
    const classes = ['saved-message'];
    if (className)
        classes.push(className);
    return ((0, jsx_runtime_1.jsxs)("div", { className: classes.join(' '), style: { opacity: show ? 1 : 0 }, children: [(0, jsx_runtime_1.jsx)(react_fontawesome_1.FontAwesomeIcon, { icon: free_solid_svg_icons_1.faCheck }, void 0), " Saved"] }, void 0));
}
exports.SavedMessage = SavedMessage;
