"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTdLink = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_router_dom_1 = require("react-router-dom");
/**
 * Makes a table cell into a link.
 *
 * `TdLink` has styles that are required for it to work correctly.
 *
 * ```
 * <table className="table table-hover table-td-link">
 *     <tbody>
 *         {products.map(p => {
 *             const Td = getTdLink('/product/detail/' + p.id)
 *
 *             return (
 *                 <tr key={p.id}>
 *                     <Td>{p.id}</Td>
 *                     <Td>{p.name}</Td>
 *                     <Td>{p.stock}</Td>
 *                 </tr>
 *             )
 *          })}
 *     </tbody>
 * </table>
 * ```
 */
function getTdLink(to, tdProps) {
    function TdLink({ children, className, ...otherProps }) {
        const classes = ['td-link'];
        if (className)
            classes.push(className);
        return ((0, jsx_runtime_1.jsx)("td", { ...tdProps, children: (0, jsx_runtime_1.jsx)(react_router_dom_1.Link, { to: to, className: classes.join(' '), ...otherProps, children: children }, void 0) }, void 0));
    }
    return TdLink;
}
exports.getTdLink = getTdLink;
