"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useReadiness = exports.allReady = void 0;
const react_1 = require("react");
/**
 * Returns true if all values in the object are true. For use with
 * [[`useReadiness`]].
 */
function allReady(readiness) {
    return Object.values(readiness).every((v) => v);
}
exports.allReady = allReady;
/**
 * Used to call `onReady` when all of the components/queries in a page are ready.
 *
 * ```
 * const [onChildReady, readiness] = useReadiness(
 *     {
 *         a: false, b: false, c: false
 *     },
 *     readiness => {
 *         if (allReady(readiness)) {
 *             onReady({ ... })
 *         }
 *     },
 * )
 * ```
 */
function useReadiness(defaultValue, onChange) {
    const [readiness, setReadiness] = (0, react_1.useState)(defaultValue);
    const onChangeRef = (0, react_1.useRef)(onChange);
    (0, react_1.useEffect)(() => {
        onChangeRef.current = onChange;
    });
    (0, react_1.useEffect)(() => {
        onChangeRef.current(readiness);
    }, [readiness]);
    const onChildReady = (0, react_1.useCallback)((delta) => {
        setReadiness((readiness) => ({ ...readiness, ...delta }));
    }, [setReadiness]);
    return [onChildReady, readiness];
}
exports.useReadiness = useReadiness;
