"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AddressInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importStar(require("react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const select_1 = require("../select");
const postalCodeValidator_1 = require("./postalCodeValidator");
const addressValidators_1 = require("./addressValidators");
const ItiReactContext_1 = require("../../ItiReactContext");
const states_1 = require("./states");
const validation_1 = require("../../validation");
const ValidatedInput_1 = require("../ValidatedInput");
const AddressInputValue_1 = require("./AddressInputValue");
/**
 * A validated address input. Supports US and Canadian addresses.
 *
 * Field lengths and the default value of `allowCanadian` are configured via
 * [[`ItiReactContext`]].
 */
exports.AddressInput = react_1.default.memo(({ showValidation, getStateSelectStyles, individualInputsRequired, enabled = true, ...otherProps }) => {
    var _a;
    const context = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext);
    const fieldLengths = context.fieldLengths.address;
    const allowCanadian = (_a = otherProps.allowCanadian) !== null && _a !== void 0 ? _a : context.addressInput.allowCanadian;
    const validators = [
        ...otherProps.validators,
        addressValidators_1.InternalAddressValidators.allFieldsValid({ allowCanadian }),
        addressValidators_1.InternalAddressValidators.allFieldLengthsValid(fieldLengths),
    ];
    if (!individualInputsRequired) {
        // this validator is only needed for optional addresses
        validators.push(addressValidators_1.InternalAddressValidators.disallowPartialAddress());
    }
    const fieldValidators = (0, react_1.useMemo)(() => {
        const baseFieldValidators = [];
        const stateValidators = [];
        if (individualInputsRequired) {
            baseFieldValidators.push(iti_react_core_1.Validators.required());
            stateValidators.push(select_1.SelectValidators.required());
        }
        return {
            line1: [...baseFieldValidators, iti_react_core_1.Validators.maxLength(fieldLengths.line1)],
            line2: [iti_react_core_1.Validators.maxLength(fieldLengths.line2)],
            city: [...baseFieldValidators, iti_react_core_1.Validators.maxLength(fieldLengths.city)],
            state: stateValidators,
            postalCode: [
                ...baseFieldValidators,
                (0, postalCodeValidator_1.postalCodeValidator)({ allowCanadian }),
            ],
        };
    }, [individualInputsRequired, fieldLengths, allowCanadian]);
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: otherProps.value,
        onChange: otherProps.onChange,
        defaultValue: otherProps.defaultValue,
        fallbackValue: AddressInputValue_1.defaultAddressInputValue,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name: otherProps.name,
        onValidChange: otherProps.onValidChange,
        validators,
        validationKey: otherProps.validationKey,
        asyncValidator: otherProps.asyncValidator,
        onAsyncError: otherProps.onAsyncError,
        formLevelValidatorOutput: otherProps.formLevelValidatorOutput,
    });
    const stateOptions = (0, react_1.useMemo)(() => (0, states_1.getStateOptions)({
        includeUsStates: true,
        includeCanadianProvinces: allowCanadian,
    }), [allowCanadian]);
    const vProps = {
        showValidation,
        validationKey: individualInputsRequired.toString(),
    };
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: (0, jsx_runtime_1.jsxs)("div", { className: "address-input", children: [(0, jsx_runtime_1.jsx)("div", { className: "address-row address-row-1", children: (0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: "line1", value: value.line1, onChange: (line1) => onChange({ ...value, line1 }), validators: fieldValidators.line1, inputAttributes: {
                            placeholder: 'Line 1',
                            'aria-label': 'Address line 1',
                        }, enabled: enabled, ...vProps }, void 0) }, void 0), (0, jsx_runtime_1.jsx)("div", { className: "address-row address-row-2", children: (0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: "line2", value: value.line2, onChange: (line2) => onChange({ ...value, line2 }), validators: fieldValidators.line2, inputAttributes: {
                            placeholder: 'Line 2',
                            'aria-label': 'Address line 2',
                        }, enabled: enabled, ...vProps }, void 0) }, void 0), (0, jsx_runtime_1.jsxs)("div", { className: "address-row address-row-3", children: [(0, jsx_runtime_1.jsx)("div", { className: "city-input-container", children: (0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: "city", value: value.city, onChange: (city) => onChange({ ...value, city }), validators: fieldValidators.city, inputAttributes: {
                                    placeholder: 'City',
                                    'aria-label': 'City',
                                }, enabled: enabled, ...vProps }, void 0) }, void 0), (0, jsx_runtime_1.jsx)("div", { className: "state-select", children: (0, jsx_runtime_1.jsx)(select_1.ValidatedSelect, { name: "state", value: value.state ? value.state.toUpperCase() : null, onChange: (0, react_1.useCallback)((state) => onChange({
                                    ...value,
                                    state: state !== null ? state : '',
                                }), [value, onChange]), options: stateOptions, width: 125, placeholder: "State", validators: fieldValidators.state, isClearable: !individualInputsRequired, "aria-label": "State", enabled: enabled, getStyles: getStateSelectStyles, ...vProps }, void 0) }, void 0), (0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: "postalCode", value: value.postalCode, onChange: (postalCode) => onChange({ ...value, postalCode }), validators: fieldValidators.postalCode, inputAttributes: {
                                placeholder: 'ZIP',
                                'aria-label': allowCanadian ? 'Postal code' : 'ZIP',
                            }, enabled: enabled, ...vProps }, void 0)] }, void 0)] }, void 0) }, void 0));
});
