"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InternalAddressValidators = exports.AddressValidators = void 0;
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const postalCodeValidator_1 = require("./postalCodeValidator");
/**
 * Only use this if making your own address input.
 */
function disallowPartialAddress() {
    return (v) => {
        const requiredValues = [v.line1, v.city, v.state, v.postalCode];
        const enteredRequiredValues = requiredValues.filter((v) => !!v).length;
        if (enteredRequiredValues !== 0 &&
            enteredRequiredValues !== requiredValues.length) {
            return ('Partial addresses are not allowed. ' +
                'Fill out all required fields or leave the address empty.');
        }
        return undefined;
    };
}
/**
 * Only use this if making your own address input.
 */
function allFieldsValid(postalCodeValidationOptions) {
    return (value) => {
        // postalCode is the only field that has validation logic
        if ((0, postalCodeValidator_1.postalCodeValidator)(postalCodeValidationOptions)(value.postalCode))
            return iti_react_core_1.INVALID_NO_FEEDBACK;
        return undefined;
    };
}
/**
 * Only use this if making your own address input.
 */
function allFieldLengthsValid(fieldLengths) {
    return (value) => {
        if (value.line1.length > fieldLengths.line1 ||
            value.line2.length > fieldLengths.line2 ||
            value.city.length > fieldLengths.city) {
            return iti_react_core_1.INVALID_NO_FEEDBACK;
        }
        return undefined;
    };
}
function required() {
    return (value) => {
        if (!(value.line1 && value.city && value.state && value.postalCode)) {
            // "This field is required." will be displayed under individual inputs
            return iti_react_core_1.INVALID_NO_FEEDBACK;
        }
        return undefined;
    };
}
/** Validators for use with [[`AddressInput`]]. */
exports.AddressValidators = {
    required,
};
/** Validators you can use to build your own custom address input. */
exports.InternalAddressValidators = {
    disallowPartialAddress,
    allFieldsValid,
    allFieldLengthsValid,
};
