"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const DateInput_1 = require("./DateInput");
test('convertJsDateToTimeZone', () => {
    // 12 pm EST / 5 pm UTC
    const easternDate = new Date('Wed Nov 13 2019 12:00:00 GMT-0500');
    // Should be 9 am PST / 5 pm UTC
    const pacificDate = (0, DateInput_1.convertJsDateToTimeZone)(easternDate, 'America/Los_Angeles');
    // at this point, we just care that year, month, day, hours, minutes, and seconds are right
    // (the offset is ignored)
    expect(pacificDate.toString()).toMatch('Wed Nov 13 2019 09:00:00');
});
test('parseJsDateIgnoringTimeZone', () => {
    const d = (0, moment_timezone_1.default)().year(2021).month(8).date(19).hour(9).minute(0).second(0);
    const date = new Date(d.format('M/D/YYYY, HH:mm:ss [GMT]ZZ'));
    const result = (0, DateInput_1.parseJsDateIgnoringTimeZone)(date, 'America/Los_Angeles');
    const losAngelesUtcOffset = -7;
    const expectedHourUtc = d.hour() - losAngelesUtcOffset;
    expect(result.toISOString()).toBe(`${d.format('YYYY-MM-DD')}T${expectedHourUtc}:00:00.000Z`);
});
describe('DateInput', () => {
    it('displays invalid feedback if the date is null', () => {
        (0, react_1.render)((0, jsx_runtime_1.jsx)(DateInput_1.DateInput, { name: "myDateInput", value: null, validators: [DateInput_1.DateValidators.required({ includesTime: false })], timeZone: "local", showValidation: true }, void 0));
        expect(react_1.screen.queryByText('You must enter a valid date (MM/DD/YYYY).')).toBeVisible();
    });
});
