"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PersonNameInput = exports.PersonNameValidators = exports.defaultPersonNameInputValue = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importStar(require("react"));
const lodash_1 = require("lodash");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../validation");
const ItiReactContext_1 = require("../ItiReactContext");
const ValidatedInput_1 = require("./ValidatedInput");
exports.defaultPersonNameInputValue = {
    first: '',
    middle: '',
    last: '',
};
const noPartialNamesValidator = (value) => {
    const allSpecified = !!(value.first && value.last);
    const allBlank = !value.first && !value.middle && !value.last;
    if (!allBlank && !allSpecified)
        return 'Both first and last name must be specified, or all fields must be left blank.';
    return undefined;
};
function required() {
    return (value) => {
        if (!(value.first && value.last))
            return 'First and last name are required.';
        return undefined;
    };
}
/** Validators for use with [[`PersonNameInput`]]. */
exports.PersonNameValidators = {
    required,
};
/**
 * A person name input that displays inputs for first name, middle name (optional), and
 * last name.
 *
 * If we just want first and last name, we will often just use two normal [[`ValidatedInputs`]]
 * instead of `PersonNameInput`.
 */
exports.PersonNameInput = react_1.default.memo(({ name, showValidation, individualInputsRequired, showMiddleNameInput = false, fluid = false, inputAttributesMap: propsInputAttributesMap = {}, enabledInputs = ['first', 'middle', 'last'], ...otherProps }) => {
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: otherProps.value,
        onChange: otherProps.onChange,
        defaultValue: otherProps.defaultValue,
        fallbackValue: exports.defaultPersonNameInputValue,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: otherProps.onValidChange,
        validators: [...otherProps.validators, noPartialNamesValidator],
        validationKey: otherProps.validationKey,
        asyncValidator: otherProps.asyncValidator,
        onAsyncError: otherProps.onAsyncError,
        formLevelValidatorOutput: otherProps.formLevelValidatorOutput,
    });
    const inputAttributesMap = (0, lodash_1.defaults)({ ...propsInputAttributesMap }, {
        prefix: {},
        first: {},
        middle: {},
        last: {},
    });
    const classes = ['person-name-input'];
    if (fluid)
        classes.push('person-name-input-fluid');
    const { onChildValidChange, allFieldsValid } = (0, iti_react_core_1.useFieldValidity)();
    const { fieldLengths } = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext);
    const firstNameValidators = [iti_react_core_1.Validators.maxLength(fieldLengths.personName.first)];
    const lastNameValidators = [iti_react_core_1.Validators.maxLength(fieldLengths.personName.last)];
    if (individualInputsRequired) {
        firstNameValidators.unshift(iti_react_core_1.Validators.required());
        lastNameValidators.unshift(iti_react_core_1.Validators.required());
    }
    const vProps = { showValidation, onValidChange: onChildValidChange };
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation && allFieldsValid, children: (0, jsx_runtime_1.jsxs)("div", { className: classes.join(' '), children: [(0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: `${name}First`, inputAttributes: {
                        placeholder: 'First',
                        'aria-label': 'First name',
                        ...inputAttributesMap.first,
                    }, enabled: enabledInputs.includes('first'), value: value.first, onChange: (first) => onChange({ ...value, first }), validators: firstNameValidators, ...vProps }, void 0), showMiddleNameInput && ((0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: `${name}Middle`, inputAttributes: {
                        placeholder: 'Middle',
                        'aria-label': 'Middle name',
                        ...inputAttributesMap.middle,
                    }, enabled: enabledInputs.includes('middle'), value: value.middle, onChange: (middle) => onChange({ ...value, middle }), 
                    // Never required because some people don't have middle names
                    validators: [
                        iti_react_core_1.Validators.maxLength(fieldLengths.personName.middle),
                    ], ...vProps }, void 0)), (0, jsx_runtime_1.jsx)(ValidatedInput_1.ValidatedInput, { name: `${name}Last`, inputAttributes: {
                        placeholder: 'Last',
                        'aria-label': 'Last name',
                        ...inputAttributesMap.last,
                    }, enabled: enabledInputs.includes('last'), value: value.last, onChange: (last) => onChange({ ...value, last }), validators: lastNameValidators, ...vProps }, void 0)] }, void 0) }, void 0));
});
