"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BooleanRadioValidators = exports.BooleanRadioInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const RadioInput_1 = require("./RadioInput");
function convertValue(value) {
    if (typeof value === 'undefined')
        return undefined;
    if (value === null)
        return null;
    return value.toString();
}
function convertValidator(validator) {
    return (value) => {
        const booleanValue = value !== null ? value === true.toString() : null;
        return validator(booleanValue);
    };
}
function convertAsyncValidator(validator) {
    return (value) => {
        const booleanValue = value !== null ? value === true.toString() : null;
        return validator(booleanValue);
    };
}
/**
 * Wrapper around [[`RadioInput`]] for when there are only two options, true and false.
 */
function BooleanRadioInput({ trueFirst = true, value, onChange, defaultValue, validators, labels = { false: 'No', true: 'Yes' }, asyncValidator, ...passThroughProps }) {
    const options = [
        { value: true.toString(), label: labels.true },
        { value: false.toString(), label: labels.false },
    ];
    if (!trueFirst)
        options.reverse();
    return ((0, jsx_runtime_1.jsx)(RadioInput_1.RadioInput, { options: options, value: convertValue(value), defaultValue: convertValue(defaultValue), onChange: (value) => {
            if (onChange)
                onChange(value === true.toString());
        }, validators: validators.map(convertValidator), asyncValidator: asyncValidator ? convertAsyncValidator(asyncValidator) : undefined, ...passThroughProps }, void 0));
}
exports.BooleanRadioInput = BooleanRadioInput;
//
//
//
function required() {
    return (value) => {
        if (value === null)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
exports.BooleanRadioValidators = {
    required,
};
