"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidatedInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importDefault(require("react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../validation");
exports.ValidatedInput = react_1.default.memo(({ id, type = 'text', showValidation, enabled = true, name, ...otherProps }) => {
    const { value, onChange: _onChange } = (0, iti_react_core_1.useControlledValue)({
        value: otherProps.value,
        onChange: otherProps.onChange,
        defaultValue: otherProps.defaultValue,
        fallbackValue: '',
    });
    function onChange(e) {
        _onChange(e.currentTarget.value);
    }
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: otherProps.onValidChange,
        validators: otherProps.validators,
        validationKey: otherProps.validationKey,
        asyncValidator: otherProps.asyncValidator,
        onAsyncError: otherProps.onAsyncError,
        formLevelValidatorOutput: otherProps.formLevelValidatorOutput,
    });
    const classes = [
        (0, validation_1.getValidationClass)(!validatorOutput, showValidation),
        'form-control',
    ];
    if (otherProps.className)
        classes.push(otherProps.className);
    const inputAttributes = { ...otherProps.inputAttributes, disabled: !enabled };
    let input;
    if (type && type.toLowerCase() === 'textarea') {
        input = ((0, jsx_runtime_1.jsx)("textarea", { id: id, name: name, className: classes.join(' '), value: value, onChange: onChange, ...inputAttributes }, void 0));
    }
    else {
        input = ((0, jsx_runtime_1.jsx)("input", { id: id, name: name, type: type, className: classes.join(' '), value: value, onChange: onChange, ...inputAttributes }, void 0));
    }
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: input }, void 0));
});
