"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidationClass = exports.ValidationFeedback = exports.useDebouncedAsyncValidationPending = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const use_debounce_1 = require("use-debounce");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const ItiReactContext_1 = require("../ItiReactContext");
/**
 * Used to show a loading indicator when async validation is progress. Uses debouncing
 * so the loading indicator is never displayed if the async validation completes quickly.
 */
function useDebouncedAsyncValidationPending(propsPending) {
    const [pending, setPending] = (0, react_1.useState)(false);
    const setPendingDebounced = (0, use_debounce_1.useDebouncedCallback)(setPending, 1000);
    (0, react_1.useEffect)(() => {
        if (propsPending) {
            setPendingDebounced(true);
        }
        else {
            setPendingDebounced.cancel();
            setPending(false);
        }
    }, [propsPending, setPendingDebounced]);
    return pending;
}
exports.useDebouncedAsyncValidationPending = useDebouncedAsyncValidationPending;
/**
 * Displays validation feedback below an input. Used by `ValidatedInput`, .etc.
 *
 * You usually won't use this directly unless creating your own input component.
 */
function ValidationFeedback({ validatorOutput, showValidation, children, renderLoadingIndicator, }) {
    const contextRenderLoadingIndicator = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext).renderLoadingIndicator;
    renderLoadingIndicator = renderLoadingIndicator !== null && renderLoadingIndicator !== void 0 ? renderLoadingIndicator : contextRenderLoadingIndicator;
    const debouncedAsyncValidationPending = useDebouncedAsyncValidationPending(validatorOutput === iti_react_core_1.ASYNC_VALIDATION_PENDING);
    let feedback;
    if (showValidation) {
        if (validatorOutput === iti_react_core_1.ASYNC_VALIDATION_PENDING) {
            if (debouncedAsyncValidationPending) {
                feedback = ((0, jsx_runtime_1.jsxs)("div", { className: "pending-feedback", children: [renderLoadingIndicator(), " Validating..."] }, void 0));
            }
        }
        else if (validatorOutput &&
            validatorOutput !== iti_react_core_1.INVALID_NO_FEEDBACK &&
            validatorOutput !== iti_react_core_1.ASYNC_VALIDATION_DEBOUNCE_PENDING) {
            feedback = (0, jsx_runtime_1.jsx)("div", { className: "invalid-feedback", children: validatorOutput }, void 0);
        }
    }
    return ((0, jsx_runtime_1.jsxs)("div", { className: "validated-input", children: [children, feedback] }, void 0));
}
exports.ValidationFeedback = ValidationFeedback;
/**
 * Returns a Bootstrap validation class depending on `valid` and `showValidation`.
 */
function getValidationClass(valid, showValidation) {
    if (showValidation) {
        if (valid)
            return 'is-valid';
        return 'is-invalid';
    }
    return '';
}
exports.getValidationClass = getValidationClass;
