"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const __testHelpers__1 = require("../__testHelpers__");
const ValidationFeedback_1 = require("./ValidationFeedback");
it('does not render feedback if valid', () => {
    (0, react_1.render)((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: undefined, showValidation: true }, void 0) }, void 0));
    expect(document.querySelector('.validated-input')).toBeEmptyDOMElement();
});
it('does not render feedback if validatorOutput=INVALID_NO_FEEDBACK', () => {
    (0, react_1.render)((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.INVALID_NO_FEEDBACK, showValidation: true }, void 0) }, void 0));
    expect(document.querySelector('.validated-input')).toBeEmptyDOMElement();
});
it('renders feedback if invalid', () => {
    (0, react_1.render)((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: "myFeedback", showValidation: true }, void 0) }, void 0));
    const invalidFeedback = document.querySelector('.invalid-feedback');
    expect(invalidFeedback).toBeVisible();
    expect(invalidFeedback).toHaveTextContent('myFeedback');
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
it('does not show loading indicator if validatorOutput=ASYNC_VALIDATION_DEBOUNCE_PENDING', async () => {
    (0, react_1.render)((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.ASYNC_VALIDATION_DEBOUNCE_PENDING, showValidation: true }, void 0) }, void 0));
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
    await (0, __testHelpers__1.waitForReactUpdates)();
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
it('shows loading indicator after a delay if validatorOutput=ASYNC_VALIDATION_PENDING', async () => {
    const { rerender } = (0, react_1.render)((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: iti_react_core_1.ASYNC_VALIDATION_PENDING, showValidation: true }, void 0) }, void 0));
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
    await (0, __testHelpers__1.waitForReactUpdates)();
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    const pendingFeedback = document.querySelector('.pending-feedback');
    expect(pendingFeedback).toBeVisible();
    expect(pendingFeedback).toHaveTextContent(/LOADING INDICATOR/);
    expect(pendingFeedback).toHaveTextContent(/Validating\.\.\./);
    rerender((0, jsx_runtime_1.jsx)(__testHelpers__1.DefaultProviders, { children: (0, jsx_runtime_1.jsx)(ValidationFeedback_1.ValidationFeedback, { validatorOutput: undefined, showValidation: true }, void 0) }, void 0));
    // Pending feedback should be removed immediately
    expect(document.querySelector('.invalid-feedback')).toBeNull();
    expect(document.querySelector('.pending-feedback')).toBeNull();
});
